@@ -3,13 +3,15 @@ Main interface for managedblockchain service type definitions.
 
 Usage::
 
-    from mypy_boto3.managedblockchain.type_defs import CreateMemberOutputTypeDef
+    ```python
+    from mypy_boto3_managedblockchain.type_defs import ApprovalThresholdPolicyTypeDef
 
-    data: CreateMemberOutputTypeDef = {...}
+    data: ApprovalThresholdPolicyTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import List
+from datetime import datetime
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -22,122 +24,59 @@ else:
 
 
 __all__ = (
+    "ApprovalThresholdPolicyTypeDef",
+    "InvitationTypeDef",
+    "InviteActionTypeDef",
+    "LogConfigurationTypeDef",
+    "LogConfigurationsTypeDef",
+    "MemberFabricAttributesTypeDef",
+    "MemberFabricConfigurationTypeDef",
+    "MemberFabricLogPublishingConfigurationTypeDef",
+    "MemberFrameworkAttributesTypeDef",
+    "MemberFrameworkConfigurationTypeDef",
+    "MemberLogPublishingConfigurationTypeDef",
+    "MemberSummaryTypeDef",
+    "MemberTypeDef",
+    "NetworkEthereumAttributesTypeDef",
+    "NetworkFabricAttributesTypeDef",
+    "NetworkFabricConfigurationTypeDef",
+    "NetworkFrameworkAttributesTypeDef",
+    "NetworkSummaryTypeDef",
+    "NetworkTypeDef",
+    "NodeEthereumAttributesTypeDef",
+    "NodeFabricAttributesTypeDef",
+    "NodeFabricLogPublishingConfigurationTypeDef",
+    "NodeFrameworkAttributesTypeDef",
+    "NodeLogPublishingConfigurationTypeDef",
+    "NodeSummaryTypeDef",
+    "NodeTypeDef",
+    "ProposalActionsTypeDef",
+    "ProposalSummaryTypeDef",
+    "ProposalTypeDef",
+    "RemoveActionTypeDef",
+    "ResponseMetadata",
+    "VoteSummaryTypeDef",
+    "VotingPolicyTypeDef",
     "CreateMemberOutputTypeDef",
     "CreateNetworkOutputTypeDef",
     "CreateNodeOutputTypeDef",
     "CreateProposalOutputTypeDef",
-    "MemberFabricAttributesTypeDef",
-    "MemberFrameworkAttributesTypeDef",
-    "LogConfigurationTypeDef",
-    "LogConfigurationsTypeDef",
-    "MemberFabricLogPublishingConfigurationTypeDef",
-    "MemberLogPublishingConfigurationTypeDef",
-    "MemberTypeDef",
     "GetMemberOutputTypeDef",
-    "NetworkFabricAttributesTypeDef",
-    "NetworkFrameworkAttributesTypeDef",
-    "ApprovalThresholdPolicyTypeDef",
-    "VotingPolicyTypeDef",
-    "NetworkTypeDef",
     "GetNetworkOutputTypeDef",
-    "NodeFabricAttributesTypeDef",
-    "NodeFrameworkAttributesTypeDef",
-    "NodeFabricLogPublishingConfigurationTypeDef",
-    "NodeLogPublishingConfigurationTypeDef",
-    "NodeTypeDef",
     "GetNodeOutputTypeDef",
-    "InviteActionTypeDef",
-    "RemoveActionTypeDef",
-    "ProposalActionsTypeDef",
-    "ProposalTypeDef",
     "GetProposalOutputTypeDef",
-    "NetworkSummaryTypeDef",
-    "InvitationTypeDef",
     "ListInvitationsOutputTypeDef",
-    "MemberSummaryTypeDef",
     "ListMembersOutputTypeDef",
     "ListNetworksOutputTypeDef",
-    "NodeSummaryTypeDef",
     "ListNodesOutputTypeDef",
-    "VoteSummaryTypeDef",
     "ListProposalVotesOutputTypeDef",
-    "ProposalSummaryTypeDef",
     "ListProposalsOutputTypeDef",
-    "MemberFabricConfigurationTypeDef",
-    "MemberFrameworkConfigurationTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MemberConfigurationTypeDef",
-    "NetworkFabricConfigurationTypeDef",
     "NetworkFrameworkConfigurationTypeDef",
     "NodeConfigurationTypeDef",
 )
 
-CreateMemberOutputTypeDef = TypedDict("CreateMemberOutputTypeDef", {"MemberId": str}, total=False)
-
-CreateNetworkOutputTypeDef = TypedDict(
-    "CreateNetworkOutputTypeDef", {"NetworkId": str, "MemberId": str}, total=False
-)
-
-CreateNodeOutputTypeDef = TypedDict("CreateNodeOutputTypeDef", {"NodeId": str}, total=False)
-
-CreateProposalOutputTypeDef = TypedDict(
-    "CreateProposalOutputTypeDef", {"ProposalId": str}, total=False
-)
-
-MemberFabricAttributesTypeDef = TypedDict(
-    "MemberFabricAttributesTypeDef", {"AdminUsername": str, "CaEndpoint": str}, total=False
-)
-
-MemberFrameworkAttributesTypeDef = TypedDict(
-    "MemberFrameworkAttributesTypeDef", {"Fabric": MemberFabricAttributesTypeDef}, total=False
-)
-
-LogConfigurationTypeDef = TypedDict("LogConfigurationTypeDef", {"Enabled": bool}, total=False)
-
-LogConfigurationsTypeDef = TypedDict(
-    "LogConfigurationsTypeDef", {"Cloudwatch": LogConfigurationTypeDef}, total=False
-)
-
-MemberFabricLogPublishingConfigurationTypeDef = TypedDict(
-    "MemberFabricLogPublishingConfigurationTypeDef",
-    {"CaLogs": LogConfigurationsTypeDef},
-    total=False,
-)
-
-MemberLogPublishingConfigurationTypeDef = TypedDict(
-    "MemberLogPublishingConfigurationTypeDef",
-    {"Fabric": MemberFabricLogPublishingConfigurationTypeDef},
-    total=False,
-)
-
-MemberTypeDef = TypedDict(
-    "MemberTypeDef",
-    {
-        "NetworkId": str,
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "FrameworkAttributes": MemberFrameworkAttributesTypeDef,
-        "LogPublishingConfiguration": MemberLogPublishingConfigurationTypeDef,
-        "Status": Literal[
-            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED"
-        ],
-        "CreationDate": datetime,
-    },
-    total=False,
-)
-
-GetMemberOutputTypeDef = TypedDict("GetMemberOutputTypeDef", {"Member": MemberTypeDef}, total=False)
-
-NetworkFabricAttributesTypeDef = TypedDict(
-    "NetworkFabricAttributesTypeDef",
-    {"OrderingServiceEndpoint": str, "Edition": Literal["STARTER", "STANDARD"]},
-    total=False,
-)
-
-NetworkFrameworkAttributesTypeDef = TypedDict(
-    "NetworkFrameworkAttributesTypeDef", {"Fabric": NetworkFabricAttributesTypeDef}, total=False
-)
-
 ApprovalThresholdPolicyTypeDef = TypedDict(
     "ApprovalThresholdPolicyTypeDef",
     {
@@ -148,118 +87,6 @@ ApprovalThresholdPolicyTypeDef = TypedDict(
     total=False,
 )
 
-VotingPolicyTypeDef = TypedDict(
-    "VotingPolicyTypeDef", {"ApprovalThresholdPolicy": ApprovalThresholdPolicyTypeDef}, total=False
-)
-
-NetworkTypeDef = TypedDict(
-    "NetworkTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "Framework": Literal["HYPERLEDGER_FABRIC"],
-        "FrameworkVersion": str,
-        "FrameworkAttributes": NetworkFrameworkAttributesTypeDef,
-        "VpcEndpointServiceName": str,
-        "VotingPolicy": VotingPolicyTypeDef,
-        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
-        "CreationDate": datetime,
-    },
-    total=False,
-)
-
-GetNetworkOutputTypeDef = TypedDict(
-    "GetNetworkOutputTypeDef", {"Network": NetworkTypeDef}, total=False
-)
-
-NodeFabricAttributesTypeDef = TypedDict(
-    "NodeFabricAttributesTypeDef", {"PeerEndpoint": str, "PeerEventEndpoint": str}, total=False
-)
-
-NodeFrameworkAttributesTypeDef = TypedDict(
-    "NodeFrameworkAttributesTypeDef", {"Fabric": NodeFabricAttributesTypeDef}, total=False
-)
-
-NodeFabricLogPublishingConfigurationTypeDef = TypedDict(
-    "NodeFabricLogPublishingConfigurationTypeDef",
-    {"ChaincodeLogs": LogConfigurationsTypeDef, "PeerLogs": LogConfigurationsTypeDef},
-    total=False,
-)
-
-NodeLogPublishingConfigurationTypeDef = TypedDict(
-    "NodeLogPublishingConfigurationTypeDef",
-    {"Fabric": NodeFabricLogPublishingConfigurationTypeDef},
-    total=False,
-)
-
-NodeTypeDef = TypedDict(
-    "NodeTypeDef",
-    {
-        "NetworkId": str,
-        "MemberId": str,
-        "Id": str,
-        "InstanceType": str,
-        "AvailabilityZone": str,
-        "FrameworkAttributes": NodeFrameworkAttributesTypeDef,
-        "LogPublishingConfiguration": NodeLogPublishingConfigurationTypeDef,
-        "Status": Literal[
-            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED", "FAILED"
-        ],
-        "CreationDate": datetime,
-    },
-    total=False,
-)
-
-GetNodeOutputTypeDef = TypedDict("GetNodeOutputTypeDef", {"Node": NodeTypeDef}, total=False)
-
-InviteActionTypeDef = TypedDict("InviteActionTypeDef", {"Principal": str})
-
-RemoveActionTypeDef = TypedDict("RemoveActionTypeDef", {"MemberId": str})
-
-ProposalActionsTypeDef = TypedDict(
-    "ProposalActionsTypeDef",
-    {"Invitations": List[InviteActionTypeDef], "Removals": List[RemoveActionTypeDef]},
-    total=False,
-)
-
-ProposalTypeDef = TypedDict(
-    "ProposalTypeDef",
-    {
-        "ProposalId": str,
-        "NetworkId": str,
-        "Description": str,
-        "Actions": ProposalActionsTypeDef,
-        "ProposedByMemberId": str,
-        "ProposedByMemberName": str,
-        "Status": Literal["IN_PROGRESS", "APPROVED", "REJECTED", "EXPIRED", "ACTION_FAILED"],
-        "CreationDate": datetime,
-        "ExpirationDate": datetime,
-        "YesVoteCount": int,
-        "NoVoteCount": int,
-        "OutstandingVoteCount": int,
-    },
-    total=False,
-)
-
-GetProposalOutputTypeDef = TypedDict(
-    "GetProposalOutputTypeDef", {"Proposal": ProposalTypeDef}, total=False
-)
-
-NetworkSummaryTypeDef = TypedDict(
-    "NetworkSummaryTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "Framework": Literal["HYPERLEDGER_FABRIC"],
-        "FrameworkVersion": str,
-        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
-        "CreationDate": datetime,
-    },
-    total=False,
-)
-
 InvitationTypeDef = TypedDict(
     "InvitationTypeDef",
     {
@@ -267,14 +94,47 @@ InvitationTypeDef = TypedDict(
         "CreationDate": datetime,
         "ExpirationDate": datetime,
         "Status": Literal["PENDING", "ACCEPTED", "ACCEPTING", "REJECTED", "EXPIRED"],
-        "NetworkSummary": NetworkSummaryTypeDef,
+        "NetworkSummary": "NetworkSummaryTypeDef",
+        "Arn": str,
     },
     total=False,
 )
 
-ListInvitationsOutputTypeDef = TypedDict(
-    "ListInvitationsOutputTypeDef",
-    {"Invitations": List[InvitationTypeDef], "NextToken": str},
+InviteActionTypeDef = TypedDict("InviteActionTypeDef", {"Principal": str})
+
+LogConfigurationTypeDef = TypedDict("LogConfigurationTypeDef", {"Enabled": bool}, total=False)
+
+LogConfigurationsTypeDef = TypedDict(
+    "LogConfigurationsTypeDef", {"Cloudwatch": "LogConfigurationTypeDef"}, total=False
+)
+
+MemberFabricAttributesTypeDef = TypedDict(
+    "MemberFabricAttributesTypeDef", {"AdminUsername": str, "CaEndpoint": str}, total=False
+)
+
+MemberFabricConfigurationTypeDef = TypedDict(
+    "MemberFabricConfigurationTypeDef", {"AdminUsername": str, "AdminPassword": str}
+)
+
+MemberFabricLogPublishingConfigurationTypeDef = TypedDict(
+    "MemberFabricLogPublishingConfigurationTypeDef",
+    {"CaLogs": "LogConfigurationsTypeDef"},
+    total=False,
+)
+
+MemberFrameworkAttributesTypeDef = TypedDict(
+    "MemberFrameworkAttributesTypeDef", {"Fabric": "MemberFabricAttributesTypeDef"}, total=False
+)
+
+MemberFrameworkConfigurationTypeDef = TypedDict(
+    "MemberFrameworkConfigurationTypeDef",
+    {"Fabric": "MemberFabricConfigurationTypeDef"},
+    total=False,
+)
+
+MemberLogPublishingConfigurationTypeDef = TypedDict(
+    "MemberLogPublishingConfigurationTypeDef",
+    {"Fabric": "MemberFabricLogPublishingConfigurationTypeDef"},
     total=False,
 )
 
@@ -289,19 +149,107 @@ MemberSummaryTypeDef = TypedDict(
         ],
         "CreationDate": datetime,
         "IsOwned": bool,
+        "Arn": str,
     },
     total=False,
 )
 
-ListMembersOutputTypeDef = TypedDict(
-    "ListMembersOutputTypeDef",
-    {"Members": List[MemberSummaryTypeDef], "NextToken": str},
+MemberTypeDef = TypedDict(
+    "MemberTypeDef",
+    {
+        "NetworkId": str,
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "FrameworkAttributes": "MemberFrameworkAttributesTypeDef",
+        "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
+        "Status": Literal[
+            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED"
+        ],
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
     total=False,
 )
 
-ListNetworksOutputTypeDef = TypedDict(
-    "ListNetworksOutputTypeDef",
-    {"Networks": List[NetworkSummaryTypeDef], "NextToken": str},
+NetworkEthereumAttributesTypeDef = TypedDict(
+    "NetworkEthereumAttributesTypeDef", {"ChainId": str}, total=False
+)
+
+NetworkFabricAttributesTypeDef = TypedDict(
+    "NetworkFabricAttributesTypeDef",
+    {"OrderingServiceEndpoint": str, "Edition": Literal["STARTER", "STANDARD"]},
+    total=False,
+)
+
+NetworkFabricConfigurationTypeDef = TypedDict(
+    "NetworkFabricConfigurationTypeDef", {"Edition": Literal["STARTER", "STANDARD"]}
+)
+
+NetworkFrameworkAttributesTypeDef = TypedDict(
+    "NetworkFrameworkAttributesTypeDef",
+    {"Fabric": "NetworkFabricAttributesTypeDef", "Ethereum": "NetworkEthereumAttributesTypeDef"},
+    total=False,
+)
+
+NetworkSummaryTypeDef = TypedDict(
+    "NetworkSummaryTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Framework": Literal["HYPERLEDGER_FABRIC", "ETHEREUM"],
+        "FrameworkVersion": str,
+        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
+        "CreationDate": datetime,
+        "Arn": str,
+    },
+    total=False,
+)
+
+NetworkTypeDef = TypedDict(
+    "NetworkTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Framework": Literal["HYPERLEDGER_FABRIC", "ETHEREUM"],
+        "FrameworkVersion": str,
+        "FrameworkAttributes": "NetworkFrameworkAttributesTypeDef",
+        "VpcEndpointServiceName": str,
+        "VotingPolicy": "VotingPolicyTypeDef",
+        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
+    total=False,
+)
+
+NodeEthereumAttributesTypeDef = TypedDict(
+    "NodeEthereumAttributesTypeDef", {"HttpEndpoint": str, "WebSocketEndpoint": str}, total=False
+)
+
+NodeFabricAttributesTypeDef = TypedDict(
+    "NodeFabricAttributesTypeDef", {"PeerEndpoint": str, "PeerEventEndpoint": str}, total=False
+)
+
+NodeFabricLogPublishingConfigurationTypeDef = TypedDict(
+    "NodeFabricLogPublishingConfigurationTypeDef",
+    {"ChaincodeLogs": "LogConfigurationsTypeDef", "PeerLogs": "LogConfigurationsTypeDef"},
+    total=False,
+)
+
+NodeFrameworkAttributesTypeDef = TypedDict(
+    "NodeFrameworkAttributesTypeDef",
+    {"Fabric": "NodeFabricAttributesTypeDef", "Ethereum": "NodeEthereumAttributesTypeDef"},
+    total=False,
+)
+
+NodeLogPublishingConfigurationTypeDef = TypedDict(
+    "NodeLogPublishingConfigurationTypeDef",
+    {"Fabric": "NodeFabricLogPublishingConfigurationTypeDef"},
     total=False,
 )
 
@@ -310,28 +258,54 @@ NodeSummaryTypeDef = TypedDict(
     {
         "Id": str,
         "Status": Literal[
-            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED", "FAILED"
+            "CREATING",
+            "AVAILABLE",
+            "UNHEALTHY",
+            "CREATE_FAILED",
+            "UPDATING",
+            "DELETING",
+            "DELETED",
+            "FAILED",
         ],
         "CreationDate": datetime,
         "AvailabilityZone": str,
         "InstanceType": str,
+        "Arn": str,
     },
     total=False,
 )
 
-ListNodesOutputTypeDef = TypedDict(
-    "ListNodesOutputTypeDef", {"Nodes": List[NodeSummaryTypeDef], "NextToken": str}, total=False
-)
-
-VoteSummaryTypeDef = TypedDict(
-    "VoteSummaryTypeDef",
-    {"Vote": Literal["YES", "NO"], "MemberName": str, "MemberId": str},
+NodeTypeDef = TypedDict(
+    "NodeTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+        "Id": str,
+        "InstanceType": str,
+        "AvailabilityZone": str,
+        "FrameworkAttributes": "NodeFrameworkAttributesTypeDef",
+        "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
+        "StateDB": Literal["LevelDB", "CouchDB"],
+        "Status": Literal[
+            "CREATING",
+            "AVAILABLE",
+            "UNHEALTHY",
+            "CREATE_FAILED",
+            "UPDATING",
+            "DELETING",
+            "DELETED",
+            "FAILED",
+        ],
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
     total=False,
 )
 
-ListProposalVotesOutputTypeDef = TypedDict(
-    "ListProposalVotesOutputTypeDef",
-    {"ProposalVotes": List[VoteSummaryTypeDef], "NextToken": str},
+ProposalActionsTypeDef = TypedDict(
+    "ProposalActionsTypeDef",
+    {"Invitations": List["InviteActionTypeDef"], "Removals": List["RemoveActionTypeDef"]},
     total=False,
 )
 
@@ -345,31 +319,174 @@ ProposalSummaryTypeDef = TypedDict(
         "Status": Literal["IN_PROGRESS", "APPROVED", "REJECTED", "EXPIRED", "ACTION_FAILED"],
         "CreationDate": datetime,
         "ExpirationDate": datetime,
+        "Arn": str,
+    },
+    total=False,
+)
+
+ProposalTypeDef = TypedDict(
+    "ProposalTypeDef",
+    {
+        "ProposalId": str,
+        "NetworkId": str,
+        "Description": str,
+        "Actions": "ProposalActionsTypeDef",
+        "ProposedByMemberId": str,
+        "ProposedByMemberName": str,
+        "Status": Literal["IN_PROGRESS", "APPROVED", "REJECTED", "EXPIRED", "ACTION_FAILED"],
+        "CreationDate": datetime,
+        "ExpirationDate": datetime,
+        "YesVoteCount": int,
+        "NoVoteCount": int,
+        "OutstandingVoteCount": int,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
+    total=False,
+)
+
+RemoveActionTypeDef = TypedDict("RemoveActionTypeDef", {"MemberId": str})
+
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+VoteSummaryTypeDef = TypedDict(
+    "VoteSummaryTypeDef",
+    {"Vote": Literal["YES", "NO"], "MemberName": str, "MemberId": str},
+    total=False,
+)
+
+VotingPolicyTypeDef = TypedDict(
+    "VotingPolicyTypeDef",
+    {"ApprovalThresholdPolicy": "ApprovalThresholdPolicyTypeDef"},
+    total=False,
+)
+
+CreateMemberOutputTypeDef = TypedDict(
+    "CreateMemberOutputTypeDef",
+    {"MemberId": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+CreateNetworkOutputTypeDef = TypedDict(
+    "CreateNetworkOutputTypeDef",
+    {"NetworkId": str, "MemberId": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+CreateNodeOutputTypeDef = TypedDict(
+    "CreateNodeOutputTypeDef", {"NodeId": str, "ResponseMetadata": "ResponseMetadata"}, total=False
+)
+
+CreateProposalOutputTypeDef = TypedDict(
+    "CreateProposalOutputTypeDef",
+    {"ProposalId": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+GetMemberOutputTypeDef = TypedDict(
+    "GetMemberOutputTypeDef",
+    {"Member": "MemberTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+GetNetworkOutputTypeDef = TypedDict(
+    "GetNetworkOutputTypeDef",
+    {"Network": "NetworkTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+GetNodeOutputTypeDef = TypedDict(
+    "GetNodeOutputTypeDef",
+    {"Node": "NodeTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+GetProposalOutputTypeDef = TypedDict(
+    "GetProposalOutputTypeDef",
+    {"Proposal": "ProposalTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListInvitationsOutputTypeDef = TypedDict(
+    "ListInvitationsOutputTypeDef",
+    {
+        "Invitations": List["InvitationTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+ListMembersOutputTypeDef = TypedDict(
+    "ListMembersOutputTypeDef",
+    {
+        "Members": List["MemberSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+ListNetworksOutputTypeDef = TypedDict(
+    "ListNetworksOutputTypeDef",
+    {
+        "Networks": List["NetworkSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+ListNodesOutputTypeDef = TypedDict(
+    "ListNodesOutputTypeDef",
+    {"Nodes": List["NodeSummaryTypeDef"], "NextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListProposalVotesOutputTypeDef = TypedDict(
+    "ListProposalVotesOutputTypeDef",
+    {
+        "ProposalVotes": List["VoteSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 ListProposalsOutputTypeDef = TypedDict(
     "ListProposalsOutputTypeDef",
-    {"Proposals": List[ProposalSummaryTypeDef], "NextToken": str},
+    {
+        "Proposals": List["ProposalSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
-MemberFabricConfigurationTypeDef = TypedDict(
-    "MemberFabricConfigurationTypeDef", {"AdminUsername": str, "AdminPassword": str}
-)
-
-MemberFrameworkConfigurationTypeDef = TypedDict(
-    "MemberFrameworkConfigurationTypeDef", {"Fabric": MemberFabricConfigurationTypeDef}, total=False
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
 )
 
 _RequiredMemberConfigurationTypeDef = TypedDict(
     "_RequiredMemberConfigurationTypeDef",
-    {"Name": str, "FrameworkConfiguration": MemberFrameworkConfigurationTypeDef},
+    {"Name": str, "FrameworkConfiguration": "MemberFrameworkConfigurationTypeDef"},
 )
 _OptionalMemberConfigurationTypeDef = TypedDict(
     "_OptionalMemberConfigurationTypeDef",
-    {"Description": str, "LogPublishingConfiguration": MemberLogPublishingConfigurationTypeDef},
+    {
+        "Description": str,
+        "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
+        "Tags": Dict[str, str],
+    },
     total=False,
 )
 
@@ -380,22 +497,22 @@ class MemberConfigurationTypeDef(
     pass
 
 
-NetworkFabricConfigurationTypeDef = TypedDict(
-    "NetworkFabricConfigurationTypeDef", {"Edition": Literal["STARTER", "STANDARD"]}
-)
-
 NetworkFrameworkConfigurationTypeDef = TypedDict(
     "NetworkFrameworkConfigurationTypeDef",
-    {"Fabric": NetworkFabricConfigurationTypeDef},
+    {"Fabric": "NetworkFabricConfigurationTypeDef"},
     total=False,
 )
 
 _RequiredNodeConfigurationTypeDef = TypedDict(
-    "_RequiredNodeConfigurationTypeDef", {"InstanceType": str, "AvailabilityZone": str}
+    "_RequiredNodeConfigurationTypeDef", {"InstanceType": str}
 )
 _OptionalNodeConfigurationTypeDef = TypedDict(
     "_OptionalNodeConfigurationTypeDef",
-    {"LogPublishingConfiguration": NodeLogPublishingConfigurationTypeDef},
+    {
+        "AvailabilityZone": str,
+        "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
+        "StateDB": Literal["LevelDB", "CouchDB"],
+    },
     total=False,
 )
 
